@@ -1,20 +1,6 @@
-# imports are in defs bellow! --------------------------------
-#backup e recover só para manutenção do server ---------------
-#senha para manutenção True ----------------------------------
-#backup e recover lançar a flag editando ---------------------
-#organizar imports para client e host ------------------------
-#fechar server só qnd n tiver ngm conectado nem editando -----
-#fechar server só para manutenção ----------------------------
-#comando backup via socket -----------------------------------
-#path_dir para cada user -------------------------------------
-#resolver backup que buga client
-#verificação se backup e recover deu certo via socket --------
-
-
+# imports are in defs bellow! 
 #dropbox, threading, socket, pathlib, tinydb, nested_dict, cryptography, json, ast
 
-
-
 class PathListEmpty(Exception):
     pass
 
@@ -77,7 +63,7 @@ def comando(msg, client):
     try:
         cmm = msg
         if cmm == 'dirfdb':
-            resp = str(dirfdb())
+            resp = str(dirfdb(path_dir_=path_dir_client))
             if resp == None:
                 client.send('Empty'.encode('utf-8'))
             else:
@@ -321,7 +307,7 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
         if path_dir_ == None:
             global path_dir
         else:
-            path_dir = path_dir_
+            path_dir = path_dir_[:]
         testa_existe_info = dirfdb(antiblock=True, return_pathed=False)
         if just_append == False:
             qntd_infos_path = len(path_dir)
@@ -358,10 +344,14 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
                 editando = False
         elif just_append == True:
             if type(valor_atualizar) == dict:
+                temp_list = list()
+                temp_list = path_dir[:]
+                path_dir_backup = path_dir[:]
                 for k, v in valor_atualizar.items():
-                    temp_list = path_dir
                     temp_list.append(k)
                     update_infodb(v, antiblock=True, path_dir_=temp_list, just_append=False)
+                    temp_list.pop(-1)
+                path_dir = path_dir_backup[:]
             else:
                 update_infodb(valor_atualizar, antiblock=True, just_append=False)
             editando = False
@@ -560,7 +550,12 @@ def close_server():
         
     else:
         raise ServerError('This command can be use only for maintenance, not allowed to host, local db or clients!')
-    
+
+def close_client():
+    if client_use:
+        client.send('close_client'.encode('utf-8'))
+        client.close()
+
 def close(travar=False):
     global editando
     if maintenance_use:
@@ -799,8 +794,3 @@ def dirfdbp():
         print(dumps(dirfdb(return_pathed=False), indent=4, ensure_ascii=False).encode('utf-8').decode())
     else:
         print(None)
-
-#inicia_db('Teste_backup_drop111.json', b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=', False, True, '10.1.1.165', 7777, 'sl.BRd0er5tzHhBwyLuxts38anKKYyr3SdBkuoIWzmpfH5Qs8WtwDndziiIdtHi2CiiL-C1-YRAZZUbxy-sUbiKOk79KjI9g-2InwwvVEFeH_wLXu6r3cPvCUW-oUdoJxVBd6bohbW8Nxo')
-#inicia_db(client_server=True, ip_host_server='10.1.1.165', port_host_server=7777)
-#inicia_host('Teste_backup_drop111.json', 'localhost', 7777, b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=', 'sl.BRd0er5tzHhBwyLuxts38anKKYyr3SdBkuoIWzmpfH5Qs8WtwDndziiIdtHi2CiiL-C1-YRAZZUbxy-sUbiKOk79KjI9g-2InwwvVEFeH_wLXu6r3cPvCUW-oUdoJxVBd6bohbW8Nxo')
-#inicia_client('localhost', 7777, b'FXRO1m_RLfY9witk54XTyf_Q0R1iMSKVdXI0SRqft40=')
